@@ -165,8 +165,8 @@ def main_posix(kind, library_ext):
     else:
         (version, _) = out.split('.', 1)
         version = int(version)
-        if version < 11 or version > 14:
-            msg = ("Building llvmlite requires LLVM 11, 12, 13, or 14, got "
+        if version != 14:
+            msg = ("Building llvmlite requires LLVM 14, got "
                    "{!r}. Be sure to set LLVM_CONFIG to the right executable "
                    "path.\nRead the documentation at "
                    "http://llvmlite.pydata.org/ for more information about "
@@ -213,7 +213,8 @@ def main_posix(kind, library_ext):
 def main():
     if sys.platform == 'win32':
         main_windows()
-    elif sys.platform.startswith('linux'):
+    elif sys.platform.startswith(('linux', 'gnu')):
+        # Linux and GNU-based OSes (e.g. GNU/Hurd), using the same Makefile
         main_posix('linux', '.so')
     elif sys.platform.startswith(('freebsd','openbsd')):
         main_posix('freebsd', '.so')
