@@ -119,8 +119,8 @@ def _uniop_intrinsic_with_flag(opname):
                 raise TypeError(
                     "expected an integer type, got %s" %
                     operand.type)
-            if not(isinstance(flag.type, types.IntType) and
-                   flag.type.width == 1):
+            if not (isinstance(flag.type, types.IntType) and
+                    flag.type.width == 1):
                 raise TypeError("expected an i1 type, got %s" % flag.type)
             fn = self.module.declare_intrinsic(
                 opname, [operand.type, flag.type])
@@ -1045,6 +1045,18 @@ class IRBuilder(object):
         self._insert(inst)
         return inst
 
+    def comment(self, text):
+        """
+        Puts a single-line comment into the generated IR. This will be ignored
+        by LLVM, but can be useful for debugging the output of a compiler. Adds
+        a comment to the source file.
+
+        * *text* is a string that does not contain new line characters.
+        """
+        inst = instructions.Comment(self.block, text)
+        self._insert(inst)
+        return inst
+
     @_uniop_intrinsic_int("llvm.bswap")
     def bswap(self, cond):
         """
